@@ -1,66 +1,9 @@
 package Module::Build::SysPath;
 
-=encoding utf-8
-
-=head1 NAME
-
-Module::Build::SysPath - install files to system folders according to FHS (or Sys::Path settings)
-
-=head1 SYNOPSIS
-
-    use Module::Build::SysPath;
-    my $builder = Module::Build::SysPath->new(
-        ...
-
-
-=head1 DESCRIPTION
-
-A subclass of L<Module::Build> using L<Sys::Path> to determine the system
-folders. Help in task of installing files into system folders and keeping
-the option to work in local distribution files while developing the module.
-
-See L<Acme::SysPath> for example usage of a module that needs a configuration
-and a folder to store templates in.
-
-=head1 USAGE
-
-=head2 module-starter
-
-    module-starter --builder=Module::Build --module=Acme::NewModule --author="Pod" --email=pod@pod
-    cd Acme-NewModule/
-    perl -lane 's/Module::Build-/Module::Build::SysPath-/; print $_;' -i Build.PL 
-    vim Build.PL
-    # s/Module::Build-/Module::Build::SysPath-/
-    # add "configure_requires => { 'Module::Build::SysPath' => 0.10 },"
-    # add "Module::Build::SysPath' => 0.10," to build_requires
-
-=head2 create SPc.pm
-
-copy L<http://github.com/jozef/Sys-Path/blob/master/examples/SPc.pm> and add
-it to your source tree. Clean up the paths that you don't need. Local distribution
-folder names can be changed to anyones taste. For example:
-
-    sub sysconfdir { File::Spec->catdir(__PACKAGE__->prefix, 'conf') };
-
-'conf' is the name of a folder with C<conffile>s. All file put to this folder
-will be installed to L<Sys::Path>->sysconfdir().
-
-=head2 use the SPc.pm
-
-Calling C<< Acme::NewModule::SPc->sysconfdir >> before the distribution is
-installed will return path to the 'conf' folder in the distribution root
-folder. Calling it after install the distribution will return L<Sys::Path>->sysconfdir().
-
-=head1 EXAMPLE
-
-See L<Acme::SysPath> for a really simple, L<Test::Daily> for a real world example.
-
-=cut
-
 use warnings;
 use strict;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use base 'Module::Build';
 use Sys::Path 0.11;
@@ -74,85 +17,6 @@ use File::Path 'make_path';
 
 our $sys_path_config_name = 'SPc';
 
-=head2 new
-
-Populates:
-
-    $builder->{'properties'}->{$path_type.'_files'} = ...;
-    $builder->{'properties'}->{'install_path'}->{$path_type} = ...;
-    $builder->add_build_element($path_type);
-
-To install files located in:
-
-	sysconfdir
-	datadir
-	docdir
-	localedir
-	webdir
-
-Files in:
-
-    cachedir
-    logdir
-    spooldir
-    rundir
-    lockdir
-    sharedstatedir
-
-are skipped during the installation. Add F<.exists> to this folders if you
-want them to be created during `./Build install`.
-
-Configuration files get a special (Debian like) treatment. All files in
-C<sysconfdir> and all files specified as C<< $builder->{'properties'}->{'conffiles'} >>
-are configuration files. Using L<Sys::Path/install_checksums> the c<conffile>s
-checksums are tracked. Here are the model situations:
-
-=over 4
-
-=item C<conffile> was never installed jet
-
-The file is just copied in place (to sysconfdir) as it is. MD5 is recorded.
-
-=item distribution ships new version, no change in system
-
-The distribution changed the C<conffile> (for example by adding new values),
-but the C<conffile> was untouched in the system. Then the new version from
-distribution replaces the one in the system.
-
-=item distribution C<conffile> wasn't changed, C<conffile> changed in system
-
-Already installed distribution is getting upgrade. Distribution C<conffile>s form
-installed and the new version didn't change. But the C<conffile> was changed in
-the system. No prompt and the C<conffile> is kept intact.
-
-=item distribution C<conffile> change, C<conffile> changed in system
-
-Already installed distribution is getting upgrade. When both the distribution
-changed the C<conffile> and the C<conffile> was changed in the system. User will
-be prompted what to do:
-
-    Installing new version of config file /etc/SOMEFILE ...
-    
-    Configuration file `/etc/SOMEFILE'
-     ==> Modified (by you or by a script) since installation.
-     ==> Package distributor has shipped an updated version.
-       What would you like to do about it ?  Your options are:
-        Y or I  : install the package maintainer's version
-        N or O  : keep your currently-installed version
-          D     : show the differences between the versions
-          Z     : background this process to examine the situation
-     The default action is to keep your current version.
-    
-    *** /etc/SOMEFILE (Y/I/N/O/D/Z) ?
-
-If N or O is selected distribution files is installed with F<-spc>
-suffix. If Y or I is selected the system C<conffile> is renamed by adding
-suffix F<-old> and distribution C<conffile> is installed.
-
-=back
-
-=cut
-
 sub new {
 	my $class = shift;
 	my $builder = $class->SUPER::new(@_);
@@ -300,14 +164,6 @@ sub new {
     return $builder;
 }
 
-=head2 ACTION_install
-
-This action is responsible for renaming files, replacing F<SPc.pm> paths
-to systems once from L<Sys::Path>. Also makes files writable (chmod 0644).
-And stores the checksums of C<conffile>s.
-
-=cut
-
 sub ACTION_install {
     my $builder = shift;
     my $destdir = $builder->{'properties'}->{'destdir'};
@@ -395,6 +251,145 @@ sub ACTION_install {
 
 __END__
 
+=encoding utf-8
+
+=head1 NAME
+
+Module::Build::SysPath - install files to system folders according to FHS (or Sys::Path settings)
+
+=head1 SYNOPSIS
+
+    use Module::Build::SysPath;
+    my $builder = Module::Build::SysPath->new(
+        ...
+
+
+=head1 DESCRIPTION
+
+A subclass of L<Module::Build> using L<Sys::Path> to determine the system
+folders. Help in task of installing files into system folders and keeping
+the option to work in local distribution files while developing the module.
+
+See L<Acme::SysPath> for example usage of a module that needs a configuration
+and a folder to store templates in.
+
+=head1 USAGE
+
+=head2 module-starter
+
+    module-starter --builder=Module::Build --module=Acme::NewModule --author="Pod" --email=pod@pod
+    cd Acme-NewModule/
+    perl -lane 's/Module::Build-/Module::Build::SysPath-/; print $_;' -i Build.PL 
+    vim Build.PL
+    # s/Module::Build-/Module::Build::SysPath-/
+    # add "configure_requires => { 'Module::Build::SysPath' => 0.10 },"
+    # add "Module::Build::SysPath' => 0.10," to build_requires
+
+=head2 create SPc.pm
+
+copy L<http://github.com/jozef/Sys-Path/blob/master/examples/SPc.pm> and add
+it to your source tree. Clean up the paths that you don't need. Local distribution
+folder names can be changed to anyones taste. For example:
+
+    sub sysconfdir { File::Spec->catdir(__PACKAGE__->prefix, 'conf') };
+
+'conf' is the name of a folder with C<conffile>s. All file put to this folder
+will be installed to L<Sys::Path>->sysconfdir().
+
+=head2 use the SPc.pm
+
+Calling C<< Acme::NewModule::SPc->sysconfdir >> before the distribution is
+installed will return path to the 'conf' folder in the distribution root
+folder. Calling it after install the distribution will return L<Sys::Path>->sysconfdir().
+
+=head1 EXAMPLE
+
+See L<Acme::SysPath> for a really simple, L<Test::Daily> for a real world example.
+
+=head2 new
+
+Populates:
+
+    $builder->{'properties'}->{$path_type.'_files'} = ...;
+    $builder->{'properties'}->{'install_path'}->{$path_type} = ...;
+    $builder->add_build_element($path_type);
+
+To install files located in:
+
+	sysconfdir
+	datadir
+	docdir
+	localedir
+	webdir
+	srvdir
+
+Folders in:
+
+    cachedir
+    logdir
+    spooldir
+    rundir
+    lockdir
+    sharedstatedir
+
+are skipped during the installation. Add F<.exists> to this folders if you
+want them to be created during `./Build install`.
+
+Configuration files get a special (Debian like) treatment. All files in
+C<sysconfdir> and all files specified as C<< $builder->{'properties'}->{'conffiles'} >>
+are configuration files. Using L<Sys::Path/install_checksums> the c<conffile>s
+checksums are tracked. Here are the model situations:
+
+=over 4
+
+=item C<conffile> was never installed jet
+
+The file is just copied in place (to sysconfdir) as it is. MD5 is recorded.
+
+=item distribution ships new version, no change in system
+
+The distribution changed the C<conffile> (for example by adding new values),
+but the C<conffile> was untouched in the system. Then the new version from
+distribution replaces the one in the system.
+
+=item distribution C<conffile> wasn't changed, C<conffile> changed in system
+
+Already installed distribution is getting upgrade. Distribution C<conffile>s form
+installed and the new version didn't change. But the C<conffile> was changed in
+the system. No prompt and the C<conffile> is kept intact.
+
+=item distribution C<conffile> change, C<conffile> changed in system
+
+Already installed distribution is getting upgrade. When both the distribution
+changed the C<conffile> and the C<conffile> was changed in the system. User will
+be prompted what to do:
+
+    Installing new version of config file /etc/SOMEFILE ...
+    
+    Configuration file `/etc/SOMEFILE'
+     ==> Modified (by you or by a script) since installation.
+     ==> Package distributor has shipped an updated version.
+       What would you like to do about it ?  Your options are:
+        Y or I  : install the package maintainer's version
+        N or O  : keep your currently-installed version
+          D     : show the differences between the versions
+          Z     : background this process to examine the situation
+     The default action is to keep your current version.
+    
+    *** /etc/SOMEFILE (Y/I/N/O/D/Z) ?
+
+If N or O is selected distribution files is installed with F<-spc>
+suffix. If Y or I is selected the system C<conffile> is renamed by adding
+suffix F<-old> and distribution C<conffile> is installed.
+
+=back
+
+=head2 ACTION_install
+
+This action is responsible for renaming files, replacing F<SPc.pm> paths
+to systems once from L<Sys::Path>. Also makes files writable (chmod 0644).
+And stores the checksums of C<conffile>s.
+
 =head1 AUTHOR
 
 Jozef Kutej, C<< <jkutej at cpan.org> >>
